@@ -18,7 +18,8 @@ after teardown => sub {
 };
 
 sub clear_database {
-    unlink $dbfile or diag "Could not unlink $dbfile: $!";
+    close($fh);
+    unlink($dbfile) or diag "Could not unlink $dbfile: $!";
 }
 
 sub _build_database {
